# xiao asgi
[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

xiao asgi is a small [ASGI](https://asgi.readthedocs.io/en/latest/) framework that can be used to create ASGI applications.
It is designed to be small in size, simple to use and have few dependencies.
HTTP and WebSockets are both supported.

## Installation

xiao asgi can be installed into a Python environment by running `pip install xiao-asgi`.

### Supported Python versions

xiao asgi has been tested with the following versions of Python:

* 3.10.0
* 3.9.7

## Documentation

Docstrings are included in the project and more information can be found at the [Wiki](https://github.com/jonathanstaniforth/xiao-asgi/wiki) tab (work in progress).

## Discussions

Head over to the [Discussions](https://github.com/jonathanstaniforth/xiao-asgi/discussions) tab to start a conversation on xiao asgi.

## Contributions

This project uses the [GitHub flow](https://guides.github.com/introduction/flow/) branching strategy.

## License

xiao asgi is open-sourced software licensed under the [MIT](https://opensource.org/licenses/MIT) license.
